Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2866)

Unified Diff: chrome/browser/services/gcm/gcm_profile_service_unittest.cc

Issue 183953005: Rename components's Encryptor to OSEncrypt. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: similarity Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/net/cookie_store_util.cc ('k') | chrome/browser/signin/local_auth.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/services/gcm/gcm_profile_service_unittest.cc
diff --git a/chrome/browser/services/gcm/gcm_profile_service_unittest.cc b/chrome/browser/services/gcm/gcm_profile_service_unittest.cc
index b3cac28fc7722ea00a3599b568ff54b75ce629c6..b79722571b06630d66af633e238893ea4b26408c 100644
--- a/chrome/browser/services/gcm/gcm_profile_service_unittest.cc
+++ b/chrome/browser/services/gcm/gcm_profile_service_unittest.cc
@@ -25,7 +25,7 @@
#include "chrome/common/extensions/features/feature_channel.h"
#include "chrome/common/pref_names.h"
#include "chrome/test/base/testing_profile.h"
-#include "components/encryptor/encryptor.h"
+#include "components/encryptor/os_crypt.h"
#include "content/public/browser/browser_thread.h"
#include "content/public/browser/notification_service.h"
#include "content/public/test/test_browser_thread_bundle.h"
@@ -504,10 +504,10 @@ class GCMProfileServiceTest : public testing::Test {
test_user_manager_.reset(new chromeos::ScopedTestUserManager());
#endif
// Encryptor ends up needing access to the keychain on OS X. So use the mock
// keychain to prevent prompts.
#if defined(OS_MACOSX)
- Encryptor::UseMockKeychain(true);
+ OSCrypt::UseMockKeychain(true);
#endif
// Create a main profile consumer.
« no previous file with comments | « chrome/browser/net/cookie_store_util.cc ('k') | chrome/browser/signin/local_auth.cc » ('j') | no next file with comments »
@@ -504,10 +504,10 @@ class GCMProfileServiceTest : public testing::Test {
test_user_manager_.reset(new chromeos::ScopedTestUserManager());
#endif
- // Encryptor ends up needing access to the keychain on OS X. So use the mock
+ // OSCrypt ends up needing access to the keychain on OS X. So use the mock
// keychain to prevent prompts.
#if defined(OS_MACOSX)

Powered by Google App Engine
This is Rietveld 408576698